import React from "react";
import PropTypes from "prop-types";
import { useTranslation } from "react-i18next";
import CanvasJSReact from "../../../../assets/js/canvasjs.react";
var CanvasJSChart = CanvasJSReact.CanvasJSChart;
var CanvasJS = CanvasJSReact.CanvasJS;
import Spinner from "../../../../components/common/Spinner";

const SessionsRunningTimeChart = ({ data }) => {
  const { t } = useTranslation();

  const addSymbols = (e) => {
    return CanvasJS.formatNumber(e.value + "h");
  };

  const dataPoints = data.map((z) => {
    return {
      x: z.orderNo,
      y: z.runningTime.hours,
      label: z.orderNo,
      indexLabel: z.runningTime.label
    };
  });

  const options = {
    animationEnabled: true,
    theme: "light2",
    title: {
      text: t("Charts.Server.Sessions.RunningTime.Title"),
      fontSize: 20
    },
    axisX: {
      title: t("Charts.Server.Sessions.RunningTime.Y"),
      reversed: true,
      interval: 1
    },
    axisY: {
      title: t("Charts.Server.Sessions.RunningTime.X"),
      labelFormatter: addSymbols
    },
    data: [
      {
        type: "bar",
        color: "#3f51b5",
        dataPoints
      }
    ]
  };

  return (
    <>
      {data.loading || !data.loaded ? (
        <Spinner />
      ) : (
        <CanvasJSChart options={options} />
      )}
    </>
  );
};

SessionsRunningTimeChart.propTypes = {
  data: PropTypes.object.isRequired
};

export default SessionsRunningTimeChart;
